summary refs log tree commit diff
path: root/distro/packages/ld-wrapper.scm
diff options
context:
space:
mode:
Diffstat (limited to 'distro/packages/ld-wrapper.scm')
-rw-r--r--distro/packages/ld-wrapper.scm18
1 files changed, 9 insertions, 9 deletions
diff --git a/distro/packages/ld-wrapper.scm b/distro/packages/ld-wrapper.scm
index 9b8a09f067..fd5a4cbd0c 100644
--- a/distro/packages/ld-wrapper.scm
+++ b/distro/packages/ld-wrapper.scm
@@ -1,4 +1,4 @@
-#!/bin/sh
+#!@BASH@
 # -*- mode: scheme; coding: utf-8; -*-
 
 # XXX: We have to go through Bash because there's no command-line switch to
@@ -7,28 +7,28 @@
 # Use `load-compiled' because `load' (and `-l') doesn't otherwise load our
 # .go file (see <http://bugs.gnu.org/12519>).
 
-main="(@ (distro packages ld-wrapper) ld-wrapper)"
+main="(@ (gnu build-support ld-wrapper) ld-wrapper)"
 exec @GUILE@ -c "(load-compiled \"$0.go\") (apply $main (cdr (command-line)))" "$@"
 !#
-;;; Guix --- Nix package management from Guile.         -*- coding: utf-8 -*-
-;;; Copyright (C) 2012 Ludovic Courtès <ludo@gnu.org>
+;;; GNU Guix --- Functional package management for GNU
+;;; Copyright © 2012 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guix.
 ;;;
 ;;; Guix is free software; you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by
 ;;; the Free Software Foundation; either version 3 of the License, or (at
 ;;; your option) any later version.
 ;;;
 ;;; Guix is distributed in the hope that it will be useful, but
 ;;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with Guix.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-(define-module (distro packages ld-wrapper)
+(define-module (gnu build-support ld-wrapper)
   #:use-module (srfi srfi-1)
   #:export (ld-wrapper))
@@ -7,28 +7,28 @@
 ;;;
-;;; This file is part of Guix.
+;;; This file is part of GNU Guix.
 ;;;
@@ -7,28 +7,28 @@
 ;;;
-;;; Guix is free software; you can redistribute it and/or modify it
+;;; GNU Guix is free software; you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by
 ;;; the Free Software Foundation; either version 3 of the License, or (at
@@ -7,28 +7,28 @@
 ;;; your option) any later version.
 ;;;
-;;; Guix is distributed in the hope that it will be useful, but
+;;; GNU Guix is distributed in the hope that it will be useful, but
 ;;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the